@@ -1,4 +1,4 @@
-package CTK::DBI; # $Id: DBI.pm 272 2019-09-26 08:45:46Z minus $
+package CTK::DBI;
 use strict;
 use utf8;
 
@@ -10,7 +10,7 @@ CTK::DBI - Database independent interface for CTKlib
 
 =head1 VERSION
 
-Version 2.30
+Version 2.31
 
 =head1 SYNOPSIS
 
@@ -20,7 +20,7 @@ Version 2.30
     # $CTK::DBI::CTK_DBI_DEBUG = 1;
 
     # MySQL connect
-    my $mso = new CTK::DBI(
+    my $mso = CTK::DBI->new(
             -dsn        => 'DBI:mysql:database=TEST;host=192.168.1.1',
             -user       => 'login',
             -pass       => 'password',
@@ -62,7 +62,7 @@ For example: print($mso->field("select sysdate() from dual"));
 =head2 new
 
     # MySQL connect
-    my $mso = new CTK::DBI(
+    my $mso = CTK::DBI->new(
             -dsn        => 'DBI:mysql:database=TEST;host=192.168.1.1',
             -user       => 'login',
             -pass       => 'password',
@@ -75,17 +75,17 @@ For example: print($mso->field("select sysdate() from dual"));
 
 Create the DBI object
 
-=head2 error
-
-    die $mso->error if $mso->error;
-
-Returns error string
-
 =head2 connect
 
     my $dbh = $mso->connect;
 
-Get DBH (DB handler)
+See L</dbh>
+
+=head2 dbh
+
+    my $dbh = $mso->dbh;
+
+Returns DBH object (DB handler of DBI)
 
 =head2 disconnect
 
@@ -93,6 +93,12 @@ Get DBH (DB handler)
 
 Forced disconnecting. Please not use this method
 
+=head2 error
+
+    die $mso->error if $mso->error;
+
+Returns error string
+
 =head2 execute
 
     # SQL
@@ -149,7 +155,7 @@ General error string
 
 =head1 DEPENDENCIES
 
-L<DBI>, L<Sys::SigAction>
+L<DBI>
 
 =head1 TO DO
 
@@ -161,15 +167,15 @@ See C<TODO> file
 
 =head1 SEE ALSO
 
-L<DBI>, L<Sys::SigAction>
+L<DBI>
 
 =head1 AUTHOR
 
-Serż Minus (Sergey Lepenkov) L<http://www.serzik.com> E<lt>abalama@cpan.orgE<gt>
+Serż Minus (Sergey Lepenkov) L<https://www.serzik.com> E<lt>abalama@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (C) 1998-2019 D&D Corporation. All Rights Reserved
+Copyright (C) 1998-2022 D&D Corporation. All Rights Reserved
 
 =head1 LICENSE
 
@@ -180,36 +186,19 @@ See C<LICENSE> file and L<https://dev.perl.org/licenses/>
 
 =cut
 
-use Carp;
-use CTK::Util qw( :API );
-
-use constant {
-    WIN             => $^O =~ /mswin/i ? 1 : 0,
-    TIMEOUT_CONNECT => 60, # timeout of connect
-    TIMEOUT_REQUEST => 60, # timeout of request
-};
+use vars qw/$VERSION/;
+$VERSION = '2.31';
 
 our $CTK_DBI_DEBUG = 0;
 our $CTK_DBI_ERROR = "";
-use vars qw/$VERSION/;
-$VERSION = '2.30';
 
-my $LOAD_SigAction = 0;
-eval 'use Sys::SigAction';
-my $es = $@;
-if ($es) {
-    eval '
-        package # hide me from PAUSE
-            Sys::SigAction;
-        sub set_sig_handler($$;$$) { 1 };
-        1;
-    ';
-    _debug("Package Sys::SigAction don't installed! Please install this package") unless WIN;
-} else {
-    $LOAD_SigAction = 1;
-}
+use Carp;
+use CTK::Util qw( :API );
+use CTK::Timeout;
+use DBI qw();
 
-use DBI();
+# Create global Timeout object
+my $to = CTK::Timeout->new();
 
 sub new {
     my $class = shift;
@@ -232,8 +221,8 @@ sub new {
             dsn         => $in[0] || '',
             user        => $in[1] // '',
             password    => $in[2] // '',
-            connect_to  => $in[3] || TIMEOUT_CONNECT,
-            request_to  => $in[4] || TIMEOUT_REQUEST,
+            connect_to  => $in[3] // 0,
+            request_to  => $in[4] // 0,
             attr        => $in[5] || undef,
             prepare_attr=> $in[6] || undef,
             debug       => $in[7] // 0,
@@ -244,9 +233,11 @@ sub new {
     # Connect
     my $_err = "";
     $args{dbh} = DBI_CONNECT($args{dsn}, $args{user}, $args{password}, $args{attr}, $args{connect_to}, \$_err);
+
+    # Create CTK::DBI object
     my $self = bless {%args}, $class;
     if ($args{dbh}) { # Ok
-        _debug(sprintf("--- DBI CONNECT {%s} ---", $args{dsn}));
+        _debug(sprintf("--- CTK::DBI CONNECT {%s} ---", $args{dsn}));
     } else {
         $self->_set_error($_err);
     }
@@ -259,36 +250,42 @@ sub _set_error {
     my $merr = shift;
     my $dbh = $self->{dbh};
 
+    # Set error string
+    $self->{error} = "";
     if (defined($merr)) {
         $self->{error} = $merr;
-    } elsif ($dbh && $dbh->can('errstr')) {
-        $self->{error} = $self->{dbh}->errstr // '';
-    } elsif (defined($DBI::errstr)) {
-        $self->{error} = $DBI::errstr;
     } else {
-        $self->{error} = "";
+        if ($dbh && $dbh->can('errstr')) {
+            $self->{error} = $dbh->errstr // '';
+        }
+        unless (length($self->{error})) {
+            $self->{error} = $DBI::errstr;
+        }
     }
+
+    # Print error if PrintError
     if ($dbh && $dbh->{PrintError}) {
         carp(sprintf("%s: %s", __PACKAGE__, $self->{error})) if length($self->{error});
     }
 
-    return undef;
+    return;
 }
 
 sub error {
     my $self = shift;
     return $self->{error} // "";
 }
-sub connect {
+sub dbh {
     # Returns dbh object
     my $self = shift;
     return $self->{dbh};
 }
+sub connect { goto &dbh }
 sub disconnect {
     my $self = shift;
     return unless $self->{dbh};
     my $rc = $self->{dbh}->disconnect;
-    _debug(sprintf("--- DBI DISCONNECT {%s} ---", $self->{dsn} || ''));
+    _debug(sprintf("--- CTK::DBI DISCONNECT {%s} ---", $self->{dsn} || ''));
     return $rc;
 }
 sub field {
@@ -340,45 +337,38 @@ sub execute {
     my $sql = shift // '';
     my @inargs = @_;
     my $dbh = $self->{dbh} || return;
+    $self->_set_error(""); # Flush errors first
     return $self->_set_error("No statement specified") unless length($sql);
-    $self->_set_error(""); # Flush errors
 
     # Prepare
     my $prepare_attr = $self->{prepare_attr};
     my %attr = ($prepare_attr && ref($prepare_attr) eq 'HASH') ? %$prepare_attr : ();
-    my $sth_ex = keys(%attr) ? $dbh->prepare($sql, {%attr}) : $dbh->prepare($sql);
+    my $sth_ex = keys(%attr)
+        ? $dbh->prepare($sql, {%attr})
+        : $dbh->prepare($sql);
     unless ($sth_ex) {
         return $self->_set_error(sprintf("Can't prepare statement \"%s\": %s", $sql, $dbh->errstr // 'unknown error'));
     }
 
     # Execute
-    my $rto = $self->{request_to};
-    my $count_execute     = 1;     # TRUE
-    my $count_execute_msg = 'ok';  # TRUE
-    eval {
-        local $SIG{ALRM} = sub { die "execute timed out ($rto sec)" } unless $LOAD_SigAction;
-        my $h = Sys::SigAction::set_sig_handler( 'ALRM' ,sub { die "execute timed out ($rto sec)" ; } );
-        eval {
-            alarm($rto);
+    my $err = "";
+    my $retval = $to->timeout_call(sub {
             unless ($sth_ex->execute(@inargs)) {
-                $count_execute     = 0; # FALSE
-                $count_execute_msg = $dbh->errstr;  # FALSE
+                $err = $dbh->errstr || "the DBI::execute method has returned false status";
             }
-            alarm(0);
-        };
-        alarm(0);
-        die $@ if $@;
-    };
-    if ( $@ ) {
-        $count_execute     = 0; # FALSE
-        $count_execute_msg = $@;
+            1;
+        }, $self->{request_to});
+    unless ($retval) {
+        $err = $to->error || "unknown error";
     }
-    unless ($count_execute) {
+
+    # Errors
+    if ($err) {
         my @repsrgs = @inargs;
         my $argb = "";
         $argb = sprintf(" with bind variables: %s", join(", ", map {defined($_) ? sprintf("\"%s\"", $_) : 'undef'} @repsrgs))
             if exists($inargs[0]);
-        return $self->_set_error(sprintf("Can't execute statement \"%s\"%s: %s", $sql, $argb || '', $count_execute_msg // 'unknown error'));
+        return $self->_set_error(sprintf("Can't execute statement \"%s\"%s: %s", $sql, $argb, $err));
     }
 
     return $sth_ex;
@@ -389,53 +379,35 @@ sub DESTROY {
     $self->disconnect();
 }
 sub DBI_CONNECT {
-    # Connect
-    # $dbh = DBI_CONNECT($dsn, $user, $password, $attr, $to, $error)
-    # IN:
-    #   <DSN>      - DSN
-    #   <USER>     - DB Username
-    #   <PASSWORD> - DB Password
-    #   <ATTR>     - Attributes DBD::* (hash-ref)
-    #   <TIMEOUT>  - Timeout value
-    #   <\ERROR>   - Reference to error scalar
-    # OUT:
-    #   $dbh - DataBase Handler Object
-    #
+    # $dbh = DBI_CONNECT($dsn, $user, $password, $attr, $timeout, \$error)
     my $db_dsn      = shift || ''; # DSN
-    my $db_user     = shift // '';
-    my $db_password = shift // '';
-    my $db_attr     = shift || {}; # E.g., {ORACLE_enable_utf8 => 1}
-    my $db_tocnt    = shift || TIMEOUT_CONNECT;
-    my $rerr        = shift;
+    my $db_user     = shift // ''; # DB Username
+    my $db_password = shift // ''; # DB Password
+    my $db_attr     = shift || {}; # Attributes DBD::* (hash-ref) E.g., {ORACLE_enable_utf8 => 1}
+    my $db_tocnt    = shift // 0;  # Timeout value
+    my $rerr        = shift;       # Reference to error scalar
        $rerr = \$CTK_DBI_ERROR unless $rerr && ref($rerr) eq 'SCALAR';
-
     my $dbh;
 
-    my $count_connect     = 1;     # TRUE
-    my $count_connect_msg = 'ok';  # TRUE
-    eval {
-        local $SIG{ALRM} = sub { die "connect timed out ($db_tocnt sec)" } unless $LOAD_SigAction;
-        my $h = Sys::SigAction::set_sig_handler( 'ALRM', sub { die "connect timed out ($db_tocnt sec)" } );
-        eval {
-            alarm($db_tocnt); #implement 2 second time out
-            unless ($dbh = DBI->connect($db_dsn, "$db_user", "$db_password", $db_attr)) {
-                $count_connect     = 0; # FALSE
-                $count_connect_msg = $DBI::errstr;
+    # Connect
+    my $err = "";
+    my $retval = $to->timeout_call(sub {
+            $dbh = DBI->connect($db_dsn, "$db_user", "$db_password", $db_attr);
+            unless ($dbh) {
+                $err = $DBI::errstr || "the DBI::connect method has returned false status";
             }
-            alarm(0);
-        };
-        alarm(0);
-        die $@ if $@;
-    };
-    if ( $@ ) {
-        # Error
-        $count_connect     = 0; # FALSE
-        $count_connect_msg = $@;
-    }
-    unless ($count_connect) {
-        $$rerr = sprintf("Can't connect to \"%s\", %s", $db_dsn, $count_connect_msg // 'unknown error');;
+            1;
+        }, $db_tocnt);
+    unless ($retval) {
+        $err = $to->error || "unknown error";
     }
 
+    # Errors
+    if ($err) {
+        $$rerr = sprintf("Can't connect to \"%s\", %s", $db_dsn, $err);
+    }
+
+    # DBI handler or undef
     return $dbh;
 }
 
