@@ -10,12 +10,12 @@ CTK::Plugin::Net - Net plugin
 
 =head1 VERSION
 
-Version 1.01
+Version 1.02
 
 =head1 SYNOPSIS
 
     use CTK;
-    my $ctk = new CTK(
+    my $ctk = CTK->new(
             plugins => "net",
         );
 
@@ -81,11 +81,11 @@ L<CTK>, L<CTK::Plugin>, L<CTK::Plugin::SFTP>, L<CTK::Plugin::FTP>
 
 =head1 AUTHOR
 
-Serż Minus (Sergey Lepenkov) L<http://www.serzik.com> E<lt>abalama@cpan.orgE<gt>
+Serż Minus (Sergey Lepenkov) L<https://www.serzik.com> E<lt>abalama@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (C) 1998-2020 D&D Corporation. All Rights Reserved
+Copyright (C) 1998-2022 D&D Corporation. All Rights Reserved
 
 =head1 LICENSE
 
@@ -97,7 +97,7 @@ See C<LICENSE> file and L<https://dev.perl.org/licenses>
 =cut
 
 use vars qw/ $VERSION /;
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 use base qw/
         CTK::Plugin::FTP
@@ -121,7 +121,7 @@ __PACKAGE__->register_method(
     # Valid data
     my $uri;
     if (ref($url) && $url->isa("URI")) { $uri = $url->clone }
-    elsif ($url) { $uri = new URI($url) }
+    elsif ($url) { $uri = URI->new($url) }
     else {
         $self->error("Incorrect URL or URI object!");
         return;
@@ -155,7 +155,7 @@ __PACKAGE__->register_method(
     # Valid data
     my $uri;
     if (ref($url) && $url->isa("URI")) { $uri = $url->clone }
-    elsif ($url) { $uri = new URI($url) }
+    elsif ($url) { $uri = URI->new($url) }
     else {
         $self->error("Incorrect URL or URI object!");
         return;
